@@ -29,7 +29,7 @@ ffibuilder.cdef(r"""
     int		LipIntVerifyMonotonicityRightRegion( int id, int *Dim, int* npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
     double	LipIntInfValue( int id, int *Dim, int *Ndata, double* x, double* Xd,double* y,  double* Lipconst, int* Index);
     double	LipIntInfValueAuto( int id, int *Dim, int *Ndata, double* x,double* Xd, double* y, int* Index);
-    double	LipIntInfValueCons( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double Lipconst, int* Index);
+    double	LipIntInfValueCons( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double *Lipconst, int* Index);
     double	LipIntInfValueConsLeftRegion( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double* Lipconst, double* Region, int* Index);
     double	LipIntInfValueConsRightRegion( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double* Lipconst, double* Region, int* Index);
     double	LipIntInfValueLocal( int id, int *Dim, int *Ndata, double* x, double* Xd,double* y);
@@ -45,8 +45,8 @@ ffibuilder.cdef(r"""
     void	LipIntInfGetScaling( int id, double *S) ;
     int		LipIntInfComputeScaling( int id, int *Dim, int *Ndata, double* XData, double* YData);
     int		LipIntInfVerifyMonotonicity( int id, int *Dim, int* npts, int* Cons,  double* XData, double* YData, double LC, double ep);
-    int		LipIntInfVerifyMonotonicityLeftRegion( int id, int *Dim, int npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
-    int		LipIntInfVerifyMonotonicityRightRegion( int id, int *Dim, int npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
+    int		LipIntInfVerifyMonotonicityLeftRegion( int id, int *Dim, int *npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
+    int		LipIntInfVerifyMonotonicityRightRegion( int id, int *Dim, int *npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
     void	LipIntInfSmoothLipschitzSimp( int id, int *Dim, int* npts,  double* XData, double* YData, double* TData,  double* LC);
     void	LipIntInfSmoothLipschitzSimpW( int id, int *Dim, int* npts,  double* XData, double* YData, double* TData,  double* LC, double* W);
     int	    STCBuildLipInterpolant( int id, int *Dim, int *Ndata, double* x, double* y);
