@@ -37,7 +37,7 @@ LIBEXP int		LipIntVerifyMonotonicityRightRegion( int id, int *Dim, int* npts, in
 /* interface to the members of SLipIntInf class ====================================== */
 LIBEXP double	LipIntInfValue( int id, int *Dim, int *Ndata, double* x, double* Xd,double* y,  double* Lipconst, int* Index);
 LIBEXP double	LipIntInfValueAuto( int id, int *Dim, int *Ndata, double* x,double* Xd, double* y, int* Index);
-LIBEXP double	LipIntInfValueCons( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double Lipconst, int* Index);
+LIBEXP double	LipIntInfValueCons( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double *LipIntInfVerifyMonotonicityLeftRegionLipconst, int* Index);
 LIBEXP double	LipIntInfValueConsLeftRegion( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double* Lipconst, double* Region, int* Index);
 LIBEXP double	LipIntInfValueConsRightRegion( int id, int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double* Lipconst, double* Region, int* Index);
 LIBEXP double	LipIntInfValueLocal( int id, int *Dim, int *Ndata, double* x, double* Xd,double* y);
@@ -54,8 +54,8 @@ LIBEXP double	LipIntInfGetLipConst( int id) ;
 LIBEXP void	LipIntInfGetScaling( int id, double *S) ;
 LIBEXP int		LipIntInfComputeScaling( int id, int *Dim, int *Ndata, double* XData, double* YData);
 LIBEXP int		LipIntInfVerifyMonotonicity( int id, int *Dim, int* npts, int* Cons,  double* XData, double* YData, double LC, double ep);
-LIBEXP int		LipIntInfVerifyMonotonicityLeftRegion( int id, int *Dim, int npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
-LIBEXP int		LipIntInfVerifyMonotonicityRightRegion( int id, int *Dim, int npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
+LIBEXP int		LipIntInfVerifyMonotonicityLeftRegion( int id, int *Dim, int *npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
+LIBEXP int		LipIntInfVerifyMonotonicityRightRegion( int id, int *Dim, int *npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps);
 LIBEXP void	LipIntInfSmoothLipschitzSimp( int id, int *Dim, int* npts,  double* XData, double* YData, double* TData,  double* LC);
 LIBEXP void	LipIntInfSmoothLipschitzSimpW( int id, int *Dim, int* npts,  double* XData, double* YData, double* TData,  double* LC, double* W);
 
