@@ -120,7 +120,7 @@ class STCInterpolant():
     def BuildLipInterpolantExplicit( self, Dim, Ndata, x, y):
         return STCBuildLipInterpolantExplicit( Dim, Ndata, x, y, self.id)
     def BuildLipInterpolantColumn( self, Dim, Ndata, x, y):
-        return STCBuildLipInterpolantColumn( self, Dim, Ndata, x, y, self.id)
+        return STCBuildLipInterpolantColumn( Dim, Ndata, x, y, self.id)
     def BuildLipInterpolantExplicitColumn( self, Dim, Ndata, x, y):
         return STCBuildLipInterpolantExplicitColumn( Dim, Ndata, x, y, self.id)
     def ValueExplicit( self, x):
@@ -159,22 +159,22 @@ class SLipInt():
         LipIntValueLocalConsRightRegion(  Dim,  Ndata, Cons,  x,  Xd, y,  Region, self.id)
     def ComputeLipschitz( self, Dim,  Ndata,  x,  y):
         LipIntComputeLipschitz(  Dim,  Ndata,  x,  y, self.id)
-    def ComputeLipschitzCV( self, Dim,  Ndata,  Xd,  y,  T,  type,  Cons,  Region,  W):
-        LipIntComputeLipschitzCV(  Dim,  Ndata,  Xd,  y,  T,  type,  Cons,  Region,  W, self.id)
-    def ComputeLipschitzSplit( self, Dim,  Ndata,  Xd,  y,  T,  ratio, type,  Cons,  Region,  W):
-        LipIntComputeLipschitzSplit(  Dim,  Ndata,  Xd,  y,  T,  ratio, type,  Cons,  Region,  W, self.id)
-    def SmoothLipschitz( self, Dim,  Ndata,   Xd,  y,  T,   LC,  fW,  fC,  fR,  W,  Cons,  Region):
-        LipIntSmoothLipschitz(  Dim,  Ndata,   Xd,  y,  T,   LC,  fW,  fC,  fR,  W,  Cons,  Region, self.id)
-    def GetLipConst( self, id):
-        LipIntGetLipConst(  id, self.id)
-    def GetScaling( self, id,  S):
-        LipIntGetScaling(  id,  S, self.id)
+    def ComputeLipschitzCV( self, Dim,  Ndata,  Xd,  y,  type,  Cons,  Region,  W):
+        return LipIntComputeLipschitzCV(  Dim,  Ndata,  Xd,  y,  type,  Cons,  Region,  W, self.id)
+    def ComputeLipschitzSplit( self, Dim,  Ndata,  Xd,  y,  ratio, type,  Cons,  Region,  W):
+        return LipIntComputeLipschitzSplit(  Dim,  Ndata,  Xd,  y,  ratio, type,  Cons,  Region,  W, self.id)
+    def SmoothLipschitz( self, Dim,  Ndata,   Xd,  y,  LC, fR,  W,  Cons,  Region):
+        return LipIntSmoothLipschitz(  Dim,  Ndata,   Xd,  y,  LC,  fR,  W,  Cons,  Region, self.id)
+    def GetLipConst( self):
+        LipIntGetLipConst(  self.id)
+    def GetScaling( self, S):
+        LipIntGetScaling(  S, self.id)
     def ComputeScaling( self, Dim,  Ndata,  XData,  YData):
         LipIntComputeScaling(  Dim,  Ndata,  XData,  YData, self.id)
     def ConvertXData( self, Dim,  npts,   XData):
-        ConvertXData(  Dim,  npts,   XData, self.id)
-    def ConvertXDataAUX( self, Dim,  npts,   XData, auxdata):
-        ConvertXDataAUX(  Dim,  npts,   XData, auxdata, self.id)
+        return ConvertXData(  Dim,  npts,   XData, self.id)
+    def ConvertXDataAUX( self, Dim,  npts,   XData):
+        return ConvertXDataAUX(  Dim,  npts,   XData, self.id)
     def	VerifyMonotonicity( self, Dim,  npts,  Cons,   XData,  YData,  LC,  eps):
         LipIntVerifyMonotonicity(  Dim,  npts,  Cons,   XData,  YData,  LC,  eps, self.id)
     def	VerifyMonotonicityLeftRegion( self, Dim,  npts,  Cons,   XData,  YData,  Region,  LC,  eps):
@@ -210,14 +210,14 @@ class SLipIntInf():
         LipIntInfComputeLipschitz( dim, npts, XData, YData, self.id)
     def Value( self, dim, npts,x,XData, YData, LipConst, Index):
         return LipIntInfValue( dim, npts,x,XData, YData, LipConst, Index, self.id)
-    def SmoothLipschitzSimp( self, Dim, npts, XData, YData, TData, LC):
-        LipIntInfSmoothLipschitzSimp(Dim, npts, XData, YData, TData, LC, self.id)
+    def SmoothLipschitzSimp( self, Dim, npts, XData, YData, LC):
+        return LipIntInfSmoothLipschitzSimp(Dim, npts, XData, YData, LC, self.id)
     def ValueAuto( self, Dim,  Ndata,  x, Xd,  y,  Index):
         return LipIntInfValueAuto( Dim,  Ndata,  x, Xd,  y,  Index, self.id)
     def ValueCons(  self, Dim,  Ndata,  Cons,  x,  Xd, y,  Lipconst,  Index):
         return LipIntInfValueCons(  Dim,  Ndata,  Cons,  x,  Xd, y,  Lipconst,  Index, self.id)
     def ValueConsLeftRegion( self, Dim,  Ndata,  Cons,  x,  Xd, y,   Lipconst,  Region,  Index):
-        return LipIntInfValueConsLeftRegion( self, Dim,  Ndata,  Cons,  x,  Xd, y,   Lipconst,  Region,  Index, self.id)
+        return LipIntInfValueConsLeftRegion( Dim,  Ndata,  Cons,  x,  Xd, y,   Lipconst,  Region,  Index, self.id)
     def ValueConsRightRegion( self, Dim,  Ndata,  Cons,  x,  Xd, y,   Lipconst,  Region,  Index):
         return LipIntInfValueConsRightRegion(  Dim,  Ndata,  Cons,  x,  Xd, y,   Lipconst,  Region,  Index, self.id)
     def ValueLocal( self, Dim,  Ndata,  x,  Xd, y):
@@ -230,16 +230,16 @@ class SLipIntInf():
         return LipIntInfValueLocalConsRightRegion( Dim,  Ndata, Cons,  x,  Xd, y,  Region, self.id)
     def ComputeLocalLipschitz( self, Dim,  Ndata,  x,  y):
         LipIntInfComputeLocalLipschitz(  Dim,  Ndata,  x,  y, self.id)
-    def ComputeLipschitzCV( self, Dim,  Ndata,  Xd,  y,  T,  type,  Cons,  Region, W):
-        LipIntInfComputeLipschitzCV(  Dim,  Ndata,  Xd,  y,  T,  type,  Cons,  Region, W, self.id)
-    def ComputeLipschitzSplit( self, Dim,  Ndata,  Xd,  y,  T,  ratio,  type,  Cons,  Region, W):
-        LipIntInfComputeLipschitzSplit(  Dim,  Ndata,  Xd,  y,  T,  ratio,  type,  Cons,  Region, W, self.id)
-    def SmoothLipschitz( self, Dim,  Ndata,   Xd,  y,  T,   LC,   fW,  fC,  fR,  W,  Cons,  Region):
-        LipIntInfSmoothLipschitz(  Dim,  Ndata,   Xd,  y,  T,   LC,   fW,  fC,  fR,  W,  Cons,  Region, self.id)
-    def GetLipConst( self, id):       
-        return LipIntInfGetLipConst(  id, self.id) 
-    def GetScaling( self, S): 
-        LipIntInfGetScaling( S, self.id) 
+    def ComputeLipschitzCV( self, Dim,  Ndata,  Xd,  y,  type,  Cons,  Region, W):
+        return LipIntInfComputeLipschitzCV(  Dim,  Ndata,  Xd,  y,   type,  Cons,  Region, W, self.id)
+    def ComputeLipschitzSplit( self, Dim,  Ndata,  Xd,  y,  ratio,  type,  Cons,  Region, W):
+        return LipIntInfComputeLipschitzSplit(  Dim,  Ndata,  Xd,  y,  ratio,  type,  Cons,  Region, W, self.id)
+    def SmoothLipschitz( self, Dim,  Ndata,   Xd,  y,  LC,  fW,  fC,  fR,  W,  Cons,  Region):
+        return LipIntInfSmoothLipschitz(  Dim,  Ndata,   Xd,  y, LC,   fW,  fC,  fR,  W,  Cons,  Region, self.id)
+    def GetLipConst( self):       
+        return LipIntInfGetLipConst(  self.id)
+    def GetScaling( self, dim): 
+        return LipIntInfGetScaling( dim, self.id) 
     def ComputeScaling( self, Dim,  Ndata,  XData,  YData):
         return LipIntInfComputeScaling( Dim,  Ndata,  XData,  YData, self.id)
     def VerifyMonotonicity( self, Dim,  npts,  Cons,   XData,  YData, LC, ep):
@@ -248,8 +248,8 @@ class SLipIntInf():
         return LipIntInfVerifyMonotonicityLeftRegion(  Dim,  npts,  Cons,   XData,  YData,  Region,  LC,  eps, self.id)
     def VerifyMonotonicityRightRegion( self, Dim,  npts,  Cons,   XData,  YData,  Region,  LC,  eps):
         return LipIntInfVerifyMonotonicityRightRegion(  Dim,  npts,  Cons,   XData,  YData,  Region,  LC,  eps, self.id)
-    def SmoothLipschitzSimpW( self, Dim,  npts,   XData,  YData,  TData,   LC,  W):
-        LipIntInfSmoothLipschitzSimpW(  Dim,  npts,   XData,  YData,  TData,   LC,  W, self.id)
+    def SmoothLipschitzSimpW( self, Dim,  npts,   XData,  YData,  LC,  W):
+        return LipIntInfSmoothLipschitzSimpW(  Dim,  npts,   XData,  YData,  LC,  W, self.id)
 
     def __del__( self):
         # destructor
@@ -674,7 +674,7 @@ def LipIntComputeLocalLipschitz(Dim, Ndata, x, y, id = 0):
 
 # Python wrapper for:
 #    void	LipIntComputeLipschitzCV(int *Dim, int *Ndata, double* Xd, double* y, double* T, int* type, int* Cons, double* Region, double *W)
-def LipIntComputeLipschitzCV(Dim, Ndata, Xd, y, T, type, Cons, Region, W, id = 0):
+def LipIntComputeLipschitzCV(Dim, Ndata, Xd, y, type, Cons, Region, W, id = 0):
     """LipIntComputeLipschitzCV
 
     Args:
@@ -696,18 +696,19 @@ def LipIntComputeLipschitzCV(Dim, Ndata, Xd, y, T, type, Cons, Region, W, id = 0
     pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
     pXdnp, pXd = convert_py_float_to_cffi( Xd)
     pynp, py = convert_py_float_to_cffi( y)
+    T = [0.0] * Ndata
     pTnp, pT = convert_py_float_to_cffi( T)
     ptypenp, ptype = convert_py_int_to_cffi( type)
     pConsnp, pCons = convert_py_int_to_cffi( Cons)
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     pWnp, pW = convert_py_float_to_cffi( W)
     fm.LipIntComputeLipschitzCV( id, pDim, pNdata, pXd, py, pT, ptype, pCons, pRegion, pW)
-    return 
+    return pTnp
 
 
 # Python wrapper for:
 #    void	LipIntComputeLipschitzSplit(int *Dim, int *Ndata, double* Xd, double* y, double* T, double* ratio,int* type, int* Cons, double* Region, double *W)
-def LipIntComputeLipschitzSplit(Dim, Ndata, Xd, y, T, ratio, type, Cons, Region, W, id = 0):
+def LipIntComputeLipschitzSplit(Dim, Ndata, Xd, y, ratio, type, Cons, Region, W, id = 0):
     """LipIntComputeLipschitzSplit
 
     Args:
@@ -730,6 +731,7 @@ def LipIntComputeLipschitzSplit(Dim, Ndata, Xd, y, T, ratio, type, Cons, Region,
     pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
     pXdnp, pXd = convert_py_float_to_cffi( Xd)
     pynp, py = convert_py_float_to_cffi( y)
+    T = [0.0] * Ndata
     pTnp, pT = convert_py_float_to_cffi( T)
     prationp, pratio = convert_py_float_to_cffi( ratio)
     ptypenp, ptype = convert_py_int_to_cffi( type)
@@ -737,12 +739,12 @@ def LipIntComputeLipschitzSplit(Dim, Ndata, Xd, y, T, ratio, type, Cons, Region,
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     pWnp, pW = convert_py_float_to_cffi( W)
     fm.LipIntComputeLipschitzSplit( id, pDim, pNdata, pXd, py, pT, pratio, ptype, pCons, pRegion, pW)
-    return 
+    return pTnp
 
 
 # Python wrapper for:
 #    void	LipIntSmoothLipschitz(int *Dim, int *Ndata,  double* Xd, double* y, double* T,  double* LC, int* fW, int* fC, int* fR, double* W, int* Cons, double* Region)
-def LipIntSmoothLipschitz(Dim, Ndata, Xd, y, T, LC, fW, fC, fR, W, Cons, Region, id = 0):
+def LipIntSmoothLipschitz(Dim, Ndata, Xd, y, LC, fR, W, Cons, Region, id = 0):
     """LipIntSmoothLipschitz
 
     Args:
@@ -767,8 +769,17 @@ def LipIntSmoothLipschitz(Dim, Ndata, Xd, y, T, LC, fW, fC, fR, W, Cons, Region,
     pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
     pXdnp, pXd = convert_py_float_to_cffi( Xd)
     pynp, py = convert_py_float_to_cffi( y)
+    T = [0.0] * Ndata
     pTnp, pT = convert_py_float_to_cffi( T)
     pLCnp, pLC = convert_py_float_to_cffi( LC)
+    if W is None:
+        fW = [0.0]
+    else:
+        fW = [1.0]
+    if Cons is None:
+        fC = [0.0]
+    else:
+        fC = [1.0]
     pfWnp, pfW = convert_py_int_to_cffi( fW)
     pfCnp, pfC = convert_py_int_to_cffi( fC)
     pfRnp, pfR = convert_py_int_to_cffi( fR)
@@ -776,7 +787,7 @@ def LipIntSmoothLipschitz(Dim, Ndata, Xd, y, T, LC, fW, fC, fR, W, Cons, Region,
     pConsnp, pCons = convert_py_int_to_cffi( Cons)
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     fm.LipIntSmoothLipschitz( id, pDim, pNdata, pXd, py, pT, pLC, pfW, pfC, pfR, pW, pCons, pRegion)
-    return 
+    return pTnp
 
 
 # Python wrapper for:
@@ -852,12 +863,12 @@ def ConvertXData(Dim, npts, XData, id = 0):
     pnptsnp, pnpts = convert_py_int_to_cffi( npts)
     pXDatanp, pXData = convert_py_float_to_cffi( XData)
     fm.ConvertXData( id, pDim, pnpts, pXData)
-    return 
+    return pXDatanp
 
 
 # Python wrapper for:
 #    void	ConvertXDataAUX(int *Dim, int* npts,  double* XData, double *auxdata)
-def ConvertXDataAUX(Dim, npts, XData, auxdata, id = 0):
+def ConvertXDataAUX(Dim, npts, XData, id = 0):
     """ConvertXDataAUX
 
     Args:
@@ -873,9 +884,10 @@ def ConvertXDataAUX(Dim, npts, XData, auxdata, id = 0):
     pDimnp, pDim = convert_py_int_to_cffi( Dim)
     pnptsnp, pnpts = convert_py_int_to_cffi( npts)
     pXDatanp, pXData = convert_py_float_to_cffi( XData)
+    auxdata = [0.0] * npts
     pauxdatanp, pauxdata = convert_py_float_to_cffi( auxdata)
     fm.ConvertXDataAUX( id, pDim, pnpts, pXData, pauxdata)
-    return 
+    return pauxdatanp
 
 
 # Python wrapper for:
@@ -1043,7 +1055,7 @@ def LipIntInfValueCons(Dim, Ndata, Cons, x, Xd, y, Lipconst, Index, id = 0):
     Returns:
         (double):
     """
-    trace( "double	LipIntInfValueCons(int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double Lipconst, int* Index)")
+    trace( "double	LipIntInfValueCons(int *Dim, int *Ndata, int* Cons, double* x, double* Xd,double* y,  double *Lipconst, int* Index)")
     pDimnp, pDim = convert_py_int_to_cffi( Dim)
     pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
     pConsnp, pCons = convert_py_int_to_cffi( Cons)
@@ -1051,7 +1063,8 @@ def LipIntInfValueCons(Dim, Ndata, Cons, x, Xd, y, Lipconst, Index, id = 0):
     pXdnp, pXd = convert_py_float_to_cffi( Xd)
     pynp, py = convert_py_float_to_cffi( y)
     pIndexnp, pIndex = convert_py_int_to_cffi( Index)
-    yy = fm.LipIntInfValueCons( id, pDim, pNdata, pCons, px, pXd, py, Lipconst, pIndex)
+    pLipconstnp, pLipconst = convert_py_float_to_cffi( Lipconst)
+    yy = fm.LipIntInfValueCons( id, pDim, pNdata, pCons, px, pXd, py, pLipconst, pIndex)
     return yy
 
 
@@ -1280,7 +1293,7 @@ def LipIntInfComputeLocalLipschitz(Dim, Ndata, x, y, id = 0):
 
 # Python wrapper for:
 #    void	LipIntInfComputeLipschitzCV(int *Dim, int *Ndata, double* Xd, double* y, double* T, int* type, int* Cons, double* Region, double *W)
-def LipIntInfComputeLipschitzCV(Dim, Ndata, Xd, y, T, type, Cons, Region, W, id = 0):
+def LipIntInfComputeLipschitzCV(Dim, Ndata, Xd, y, type, Cons, Region, W, id = 0):
     """LipIntInfComputeLipschitzCV
 
     Args:
@@ -1302,18 +1315,19 @@ def LipIntInfComputeLipschitzCV(Dim, Ndata, Xd, y, T, type, Cons, Region, W, id
     pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
     pXdnp, pXd = convert_py_float_to_cffi( Xd)
     pynp, py = convert_py_float_to_cffi( y)
+    T = [0.0] * Ndata
     pTnp, pT = convert_py_float_to_cffi( T)
     ptypenp, ptype = convert_py_int_to_cffi( type)
     pConsnp, pCons = convert_py_int_to_cffi( Cons)
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     pWnp, pW = convert_py_float_to_cffi( W)
     fm.LipIntInfComputeLipschitzCV( id, pDim, pNdata, pXd, py, pT, ptype, pCons, pRegion, pW)
-    return 
+    return pTnp
 
 
 # Python wrapper for:
 #    void	LipIntInfComputeLipschitzSplit(int *Dim, int *Ndata, double* Xd, double* y, double* T, double* ratio, int* type, int* Cons, double* Region, double *W)
-def LipIntInfComputeLipschitzSplit(Dim, Ndata, Xd, y, T, ratio, type, Cons, Region, W, id = 0):
+def LipIntInfComputeLipschitzSplit(Dim, Ndata, Xd, y, ratio, type, Cons, Region, W, id = 0):
     """LipIntInfComputeLipschitzSplit
 
     Args:
@@ -1336,6 +1350,7 @@ def LipIntInfComputeLipschitzSplit(Dim, Ndata, Xd, y, T, ratio, type, Cons, Regi
     pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
     pXdnp, pXd = convert_py_float_to_cffi( Xd)
     pynp, py = convert_py_float_to_cffi( y)
+    T = [0.0] * Ndata
     pTnp, pT = convert_py_float_to_cffi( T)
     prationp, pratio = convert_py_float_to_cffi( ratio)
     ptypenp, ptype = convert_py_int_to_cffi( type)
@@ -1343,12 +1358,12 @@ def LipIntInfComputeLipschitzSplit(Dim, Ndata, Xd, y, T, ratio, type, Cons, Regi
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     pWnp, pW = convert_py_float_to_cffi( W)
     fm.LipIntInfComputeLipschitzSplit( id, pDim, pNdata, pXd, py, pT, pratio, ptype, pCons, pRegion, pW)
-    return 
+    return pTnp
 
 
 # Python wrapper for:
-#    void	LipIntInfSmoothLipschitz(int *Dim, int *Ndata,  double* Xd, double* y, double* T,  double* LC,  int* fW, int* fC, int* fR, double* W, int* Cons, double* Region)
-def LipIntInfSmoothLipschitz(Dim, Ndata, Xd, y, T, LC, fW, fC, fR, W, Cons, Region, id = 0):
+#    void LipIntInfSmoothLipschitz(int *Dim, int *Ndata,  double* Xd, double* y, double* T,  double* LC,  int* fW, int* fC, int* fR, double* W, int* Cons, double* Region)
+def LipIntInfSmoothLipschitz(Dim, Ndata, Xd, y, LC, fW, fC, fR, W, Cons, Region, id = 0):
     """LipIntInfSmoothLipschitz
 
     Args:
@@ -1373,6 +1388,7 @@ def LipIntInfSmoothLipschitz(Dim, Ndata, Xd, y, T, LC, fW, fC, fR, W, Cons, Regi
     pNdatanp, pNdata = convert_py_int_to_cffi( Ndata)
     pXdnp, pXd = convert_py_float_to_cffi( Xd)
     pynp, py = convert_py_float_to_cffi( y)
+    T = [0.0] * Ndata 
     pTnp, pT = convert_py_float_to_cffi( T)
     pLCnp, pLC = convert_py_float_to_cffi( LC)
     pfWnp, pfW = convert_py_int_to_cffi( fW)
@@ -1382,7 +1398,7 @@ def LipIntInfSmoothLipschitz(Dim, Ndata, Xd, y, T, LC, fW, fC, fR, W, Cons, Regi
     pConsnp, pCons = convert_py_int_to_cffi( Cons)
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     fm.LipIntInfSmoothLipschitz( id, pDim, pNdata, pXd, py, pT, pLC, pfW, pfC, pfR, pW, pCons, pRegion)
-    return 
+    return pTnp
 
 
 # Python wrapper for:
@@ -1402,7 +1418,7 @@ def LipIntInfGetLipConst( id = 0):
 
 # Python wrapper for:
 #    void	LipIntInfGetScaling(double *S) 
-def LipIntInfGetScaling(S, id = 0):
+def LipIntInfGetScaling( dim, id = 0):
     """LipIntInfGetScaling
 
     Args:
@@ -1412,9 +1428,10 @@ def LipIntInfGetScaling(S, id = 0):
         <none>
     """
     trace( "void	LipIntInfGetScaling(double *S) ")
+    S = [0.0] * dim
     pSnp, pS = convert_py_float_to_cffi( S)
     fm.LipIntInfGetScaling( id, pS)
-    return 
+    return pSnp
 
 
 # Python wrapper for:
@@ -1485,20 +1502,21 @@ def LipIntInfVerifyMonotonicityLeftRegion(Dim, npts, Cons, XData, YData, Region,
     Returns:
         (int):
     """
-    trace( "int		LipIntInfVerifyMonotonicityLeftRegion(int *Dim, int npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps)")
+    trace( "int		LipIntInfVerifyMonotonicityLeftRegion(int *Dim, int *npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps)")
     pDimnp, pDim = convert_py_int_to_cffi( Dim)
+    pnptsnp, pnpts = convert_py_int_to_cffi( npts)
     pConsnp, pCons = convert_py_int_to_cffi( Cons)
     pXDatanp, pXData = convert_py_float_to_cffi( XData)
     pYDatanp, pYData = convert_py_float_to_cffi( YData)
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     pLCnp, pLC = convert_py_float_to_cffi( LC)
     pepsnp, peps = convert_py_float_to_cffi( eps)
-    yy = fm.LipIntInfVerifyMonotonicityLeftRegion( id, pDim, npts, pCons, pXData, pYData, pRegion, pLC, peps)
+    yy = fm.LipIntInfVerifyMonotonicityLeftRegion( id, pDim, pnpts, pCons, pXData, pYData, pRegion, pLC, peps)
     return yy
 
 
 # Python wrapper for:
-#    int		LipIntInfVerifyMonotonicityRightRegion(int *Dim, int npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps)
+#    int		LipIntInfVerifyMonotonicityRightRegion(int *Dim, int *npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps)
 def LipIntInfVerifyMonotonicityRightRegion(Dim, npts, Cons, XData, YData, Region, LC, eps, id = 0):
     """LipIntInfVerifyMonotonicityRightRegion
 
@@ -1517,19 +1535,20 @@ def LipIntInfVerifyMonotonicityRightRegion(Dim, npts, Cons, XData, YData, Region
     """
     trace( "int		LipIntInfVerifyMonotonicityRightRegion(int *Dim, int npts, int* Cons,  double* XData, double* YData, double* Region, double* LC, double* eps)")
     pDimnp, pDim = convert_py_int_to_cffi( Dim)
+    pnptsnp, pnpts = convert_py_int_to_cffi( npts)
     pConsnp, pCons = convert_py_int_to_cffi( Cons)
     pXDatanp, pXData = convert_py_float_to_cffi( XData)
     pYDatanp, pYData = convert_py_float_to_cffi( YData)
     pRegionnp, pRegion = convert_py_float_to_cffi( Region)
     pLCnp, pLC = convert_py_float_to_cffi( LC)
     pepsnp, peps = convert_py_float_to_cffi( eps)
-    yy = fm.LipIntInfVerifyMonotonicityRightRegion( id, pDim, npts, pCons, pXData, pYData, pRegion, pLC, peps)
+    yy = fm.LipIntInfVerifyMonotonicityRightRegion( id, pDim, pnpts, pCons, pXData, pYData, pRegion, pLC, peps)
     return yy
 
 
 # Python wrapper for:
 #    void	LipIntInfSmoothLipschitzSimp(int *Dim, int* npts,  double* XData, double* YData, double* TData,  double* LC)
-def LipIntInfSmoothLipschitzSimp(Dim, npts, XData, YData, TData, LC, id = 0):
+def LipIntInfSmoothLipschitzSimp(Dim, npts, XData, YData, LC, id = 0):
     """LipIntInfSmoothLipschitzSimp
 
     Args:
@@ -1548,15 +1567,16 @@ def LipIntInfSmoothLipschitzSimp(Dim, npts, XData, YData, TData, LC, id = 0):
     pnptsnp, pnpts = convert_py_int_to_cffi( npts)
     pXDatanp, pXData = convert_py_float_to_cffi( XData)
     pYDatanp, pYData = convert_py_float_to_cffi( YData)
+    TData = [0.0] * npts
     pTDatanp, pTData = convert_py_float_to_cffi( TData)
     pLCnp, pLC = convert_py_float_to_cffi( LC)
     fm.LipIntInfSmoothLipschitzSimp( id, pDim, pnpts, pXData, pYData, pTData, pLC)
-    return 
+    return pTDatanp
 
 
 # Python wrapper for:
 #    void	LipIntInfSmoothLipschitzSimpW(int *Dim, int* npts,  double* XData, double* YData, double* TData,  double* LC, double* W)
-def LipIntInfSmoothLipschitzSimpW(Dim, npts, XData, YData, TData, LC, W, id = 0):
+def LipIntInfSmoothLipschitzSimpW(Dim, npts, XData, YData, LC, W, id = 0):
     """LipIntInfSmoothLipschitzSimpW
 
     Args:
@@ -1576,11 +1596,12 @@ def LipIntInfSmoothLipschitzSimpW(Dim, npts, XData, YData, TData, LC, W, id = 0)
     pnptsnp, pnpts = convert_py_int_to_cffi( npts)
     pXDatanp, pXData = convert_py_float_to_cffi( XData)
     pYDatanp, pYData = convert_py_float_to_cffi( YData)
+    TData = [0.0] * npts
     pTDatanp, pTData = convert_py_float_to_cffi( TData)
     pLCnp, pLC = convert_py_float_to_cffi( LC)
     pWnp, pW = convert_py_float_to_cffi( W)
     fm.LipIntInfSmoothLipschitzSimpW( id, pDim, pnpts, pXData, pYData, pTData, pLC, pW)
-    return 
+    return pTDatanp
 
 
 # Python wrapper for:
